@@ -10,14 +10,14 @@ package Devel::Cover::Report::Html;
 use strict;
 use warnings;
 
-our $VERSION = "0.15";
+our $VERSION = "0.16";
 
-use Devel::Cover::DB        0.15;
-use Devel::Cover::Statement 0.15;
-use Devel::Cover::Branch    0.15;
-use Devel::Cover::Condition 0.15;
-use Devel::Cover::Pod       0.15;
-use Devel::Cover::Time      0.15;
+use Devel::Cover::DB        0.16;
+use Devel::Cover::Statement 0.16;
+use Devel::Cover::Branch    0.16;
+use Devel::Cover::Condition 0.16;
+use Devel::Cover::Pod       0.16;
+use Devel::Cover::Time      0.16;
 
 use Cwd ();
 use Template 2.00;
@@ -78,7 +78,7 @@ sub print_summary
     };
 
     my $html = "$db->{db}/$db->{db}.html";
-    $Template->process("html/summary", $vars, $html) or die $Template->error();
+    $Template->process("summary", $vars, $html) or die $Template->error();
 
     my $cwd = Cwd::cwd();
     print "HTML output sent to $cwd/$html\n";
@@ -161,7 +161,7 @@ sub print_file
     };
 
     my $html = "$db->{db}/$Filenames{$file}.html";
-    $Template->process("html/file", $vars, $html) or die $Template->error();
+    $Template->process("file", $vars, $html) or die $Template->error();
 }
 
 sub print_branches
@@ -201,7 +201,7 @@ sub print_branches
     };
 
     my $html = "$db->{db}/$Filenames{$file}--branch.html";
-    $Template->process("html/branches", $vars, $html) or die $Template->error();
+    $Template->process("branches", $vars, $html) or die $Template->error();
 }
 
 sub print_conditions
@@ -257,7 +257,7 @@ sub print_conditions
     # print Dumper $vars;
 
     my $html = "$db->{db}/$Filenames{$file}--condition.html";
-    $Template->process("html/conditions", $vars, $html)
+    $Template->process("conditions", $vars, $html)
         or die $Template->error();
 }
 
@@ -267,8 +267,10 @@ sub report
 
     $Template = Template->new
     ({
-        EVAL_PERL    => 0,
-        INCLUDE_PATH => [ "./templates" ],
+        LOAD_TEMPLATES =>
+        [
+            Devel::Cover::Report::Html::Template::Provider->new({}),
+        ],
     });
 
     %Filenames   = map { $_ => do { (my $f = $_) =~ s/\W/-/g; $f } }
@@ -285,6 +287,238 @@ sub report
     }
 }
 
+1;
+
+package Devel::Cover::Report::Html::Template::Provider;
+
+use strict;
+use warnings;
+
+our $VERSION = "0.16";
+
+use base "Template::Provider";
+
+my %Templates;
+
+sub fetch
+{
+    my $self = shift;
+    my ($name) = @_;
+    # print "Looking for <$name>\n";
+    $self->SUPER::fetch(exists $Templates{$name} ? \$Templates{$name} : $name)
+}
+
+$Templates{colours} = <<'EOT';
+[%
+    colours =
+    {
+        default => "#ffffad",
+        text    => "#000000",
+        number  => "#ffffc0",
+        error   => "#ff0000",
+        ok      => "#00ff00",
+    }
+%]
+
+[% MACRO bg BLOCK -%]
+bgcolor="[% colours.$colour %]"
+[%- END %]
+EOT
+
+$Templates{html} = <<'EOT';
+[% PROCESS colours %]
+
+<!--
+
+This file was generated by Devel::Cover Version 0.16
+
+Devel::Cover is copyright 2001-2002, Paul Johnson (pjcj@cpan.org)
+
+Devel::Cover is free.  It is licensed under the same terms as Perl itself.
+
+The latest version of Devel::Cover should be available from my homepage:
+http://www.pjcj.net
+
+-->
+
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE html
+    PUBLIC "-//W3C//DTD XHTML Basic 1.0//EN"
+    "http://www.w3.org/TR/xhtml-basic/xhtml-basic10.dtd">
+<html xmlns="http://www.w3.org/1999/xhtml" lang="en-US">
+<head>
+    <title> [% title %] </title>
+</head>
+<body [% bg(colour = "default") %] text="[% colours.text %]">
+    [% content %]
+</body>
+</html>
+EOT
+
+$Templates{summary} = <<'EOT';
+[% WRAPPER html %]
+
+<h1> [% title %] </h1>
+
+<table border="2">
+
+    <tr align="RIGHT" valign="CENTER">
+        <th align="LEFT"> File </th>
+        [% FOREACH header = headers %]
+            <th> [% header %] </th>
+        [% END %]
+    </tr>
+
+    [% FOREACH file = files %]
+        <tr align="RIGHT" valign="CENTER">
+            <td align="LEFT">
+                [% IF file_exists.$file %]
+                    <a href="[%- filenames.$file -%].html"> [% file %] </a>
+                [% ELSE %]
+                    [% file %]
+                [% END %]
+            </td>
+
+            [% FOREACH criterion = showing %]
+                [% IF vals.$file.$criterion.bg %]
+                    <td bgcolor="[%- vals.$file.$criterion.bg -%]">
+                [% ELSE %]
+                    <td>
+                [% END %]
+                    [% vals.$file.$criterion.pc %]
+                </td>
+            [% END %]
+        </tr>
+    [% END %]
+
+</table>
+
+[% END %]
+EOT
+
+$Templates{branches} = <<'EOT';
+[% PROCESS colours %]
+
+[% WRAPPER html %]
+
+<h1> [% title %] </h1>
+
+<table>
+
+    <tr align="RIGHT" valign="CENTER">
+        <th> line </th>
+        <th> % </th>
+        <th> 1 </th>
+        <th> 2 </th>
+        <th align="CENTER"> branch </th>
+    </tr>
+
+    [% FOREACH branch = branches %]
+        <a name="[% branch.ref %]"> </a>
+        <tr align="RIGHT" valign="CENTER">
+            <td [% bg(colour = "number") %]> [% branch.number %] </td>
+            <td [% bg(colour = branch.bg) %]> [% branch.percentage %] </td>
+            [% FOREACH part = branch.parts %]
+                <td [% bg(colour = part.bg) %]> [% part.text %] </td>
+            [% END %]
+            <td [% bg(colour = branch.bg) %] align="LEFT">
+                <pre> [% branch.text %]</pre>
+            </td>
+        </tr>
+    [% END %]
+
+</table>
+
+[% END %]
+EOT
+
+$Templates{conditions} = <<'EOT';
+[% PROCESS colours %]
+
+[% WRAPPER html %]
+
+<h1> [% title %] </h1>
+
+[% FOREACH type = types %]
+
+    <h2> [% type.name %] conditions </h2>
+
+    <table>
+
+        <tr align="RIGHT" valign="CENTER">
+            <th> line </th>
+            <th> % </th>
+            [% FOREACH header = type.headers %]
+                <th> [% header %] </th>
+            [% END %]
+            <th align="CENTER"> condition </th>
+        </tr>
+
+        [% FOREACH condition = type.conditions %]
+            <a name="[% condition.ref %]"> </a>
+            <tr align="RIGHT" valign="CENTER">
+                <td [% bg(colour = "number") %]> [% condition.number %] </td>
+                <td [% bg(colour = condition.bg) %]>
+                    [% condition.percentage %]
+                </td>
+                [% FOREACH part = condition.parts %]
+                    <td [% bg(colour = part.bg) %]> [% part.text %] </td>
+                [% END %]
+                <td [% bg(colour = condition.bg) %] align="LEFT">
+                    <pre> [% condition.text %]</pre>
+                </td>
+            </tr>
+        [% END %]
+
+    </table>
+
+[% END %]
+
+[% END %]
+EOT
+
+$Templates{file} = <<'EOT';
+[% PROCESS colours %]
+
+[% WRAPPER html %]
+
+<h1> [% title %] </h1>
+
+<table>
+
+    <tr align="RIGHT" valign="CENTER">
+        <th> </th>
+        [% FOREACH header = headers %]
+            <th> [% header %] </th>
+        [% END %]
+        <th align="CENTER"> code </th>
+    </tr>
+
+    [% FOREACH line = lines %]
+        <tr align="RIGHT" valign="CENTER">
+            <td [% bg(colour = "number") %]> [% line.number %] </td>
+            [% FOREACH cr = line.criteria %]
+                <td [% bg(colour = cr.bg) %]>
+                    [% IF cr.link.defined && cr.text %]
+                    <a href="[% cr.link %]">
+                    [% END %]
+                    [% cr.text %]
+                    [% IF cr.link.defined && cr.text %]
+                    </a>
+                    [% END %]
+                </td>
+            [% END %]
+            <td [% bg(colour = line.bg) %] align="LEFT">
+                <pre> [% line.text %]</pre>
+            </td>
+        </tr>
+    [% END %]
+
+</table>
+
+[% END %]
+EOT
+
 1
 
 __END__
@@ -315,7 +549,7 @@ Huh?
 
 =head1 VERSION
 
-Version 0.15 - 5th September 2002
+Version 0.16 - 9th September 2002
 
 =head1 LICENCE
 
